@@ -2,7 +2,7 @@
 Base DynamoDB streams Lambda application
 """
 from aws_lambda_powertools.utilities.data_classes import DynamoDBStreamEvent
-from spine_aws_common.batch_application import BatchApplication
+from octo_aws_common.batch_application import BatchApplication
 
 
 class DynamoDBStreamsApplication(BatchApplication):
